@@ -2,6 +2,8 @@ package Gitalist::Controller;
 use Moose;
 use namespace::autoclean;
 
-BEGIN { extends 'Catalyst::Controller::ActionRole' }
+BEGIN { extends 'Catalyst::Controller' }
 
 __PACKAGE__->meta->make_immutable;
+1;
+
